{
  "namespace": "org.radarcns.connector.upload.altoida",
  "type": "record",
  "name": "AltoidaMagneticField",
  "doc": "Data from 3-axis magnetometer sensor micro Tesla units (µT).",
  "fields": [
    {"name": "time", "type": "double", "doc": "Timestamp in unix time acquired locally from the device."},
    {"name": "timeReceived", "type": "double", "doc": "Timestamp in unix time received from Altoida API."},
    {"name": "x", "type": "float", "doc": "Earths magnetic field along the x-axis in µT."},
    {"name": "y", "type": "float", "doc": "Earths magnetic field along the y-axis in µT."},
    {"name": "z", "type": "float", "doc": "Earths magnetic field along the z-axis in µT."},
    {"name": "accuracy", "type": "string", "doc": "Accuracy of measurement magnetometer low, medium, high and uncalibrated."}
  ]
}
