{
  "namespace": "org.radarcns.passive.pebble",
  "type": "record",
  "name": "Pebble2HeartRate",
  "doc": "Raw heart rate from the Pebble 2 Heart Monitor. You can compute the inter beat interval rate as (60 / heartRate).",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "heartRate", "type": "float", "doc": "Heart rate (bpm)." }
  ]
}
