{
  "namespace": "org.radarcns.passive.bittium",
  "type": "record",
  "name": "BittiumFarosTemperature",
  "doc": "Data from an Bittium Faros' temperature sensor.",
  "fields": [
    {"name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    {"name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    {"name": "temperature", "type": "float", "doc": "Skin temperature (°C) converted from analog-to-digital converter (ADC) values. Conversion is reliable between 35 and 45 degrees Celcius." }
  ]
}
