{
  "namespace": "org.radarcns.active.task",
  "type": "record",
  "name": "Task",
  "doc": "General schema for tasks. Check the specification folder to see how the task has been defined. For each TaskType there is a JSON file reporting the tasks set and possible answers if available.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Timestamp in UTC (s) when the task is submitted to the subject." },
    { "name": "timeCompleted", "type": "double", "doc": "Timestamp in UTC (s) when subject marks the task as complete." },
    { "name": "name", "type": "string", "doc": "Task names." },
    { "name": "version", "type": "string", "doc": "It reports the task version stated in the JSON specification." },
    { "name": "answers", "type": {
      "type": "array",
      "items": {
        "name": "Answer",
        "type": "record",
        "doc": "Task answer.",
         "fields": [
           { "name": "questionId", "type": ["null", "string"], "doc": "Unique identifier for the specific question.", "default": null },
           { "name": "value", "type": ["int", "string", "double"], "doc": "Subject answer." },
           { "name": "startTime", "type": "double", "doc": "Timestamp in UTC (s) when the task is shown." },
           { "name": "endTime", "type": "double", "doc": "Timestamp in UTC (s)  when the task is answered." }
         ]
       }}, "doc": "Answers list. The answers order must follow the task order."}
  ]
}
