{
  "namespace": "org.radarcns.kafka",
  "type": "record",
  "name": "AggregateKey",
  "doc": "Key of an aggregated stream. The stream will work with time windows.",
  "fields": [
    {"name": "projectId", "type": ["null", "string"], "doc": "Project that the key belongs to.", "default": null},
    {"name": "userId", "type": "string", "doc": "User Identifier created during the enrolment."},
    {"name": "sourceId", "type": "string", "doc": "Unique identifier associated with the source."},
    {"name": "timeStart", "type": "double", "doc": "Time (seconds since the UNIX Epoch) of the time window start."},
    {"name": "timeEnd", "type": "double", "doc": "Time (seconds since the UNIX Epoch) of the time window end."}
  ]
}
