{
  "namespace": "org.radarcns.passive.biovotion",
  "type": "record",
  "name": "BiovotionVsm1HeartRateVariability",
  "doc": "Heart rate variability data calculated by biovotion device.",
  "fields": [
    {"name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    {"name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    {"name": "heartRateVariability", "type": "float", "doc": "Heart rate variability value. The applied metric is the root mean squared of successive differences (RMSSD) of heart pulses, measured in milliseconds." },
    {"name": "heartRateVariabilityQuality", "type": "float", "doc": "Heart rate variability quality (0-1)." }
  ]
}
