{
  "namespace": "org.radarcns.active.thincit",
  "type": "record",
  "name": "ThincItPdq",
  "doc": "THINC-it Assessment derived from PDQ5.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Timestamp in UTC (s) when the test is submitted to the subject." },
    { "name": "timeCompleted", "type": "double", "doc": "Timestamp in UTC (s) when the subject completes the test." },
    { "name": "score", "type": "int", "doc": "THINC-it index score - 0 to 4000." },
    { "name": "questionOne", "type":
      {
        "type": "enum",
        "name": "ThincItPdqQuestion",
        "doc": "PDQ5 question.",
        "symbols": [
            "NEVER",
            "RARELY",
            "SOMETIMES",
            "OFTEN",
            "VERYOFTEN"
        ]
      }, "doc": "PDQ5 Question 1."},
    { "name": "questionTwo", "type": "ThincItPdqQuestion", "doc": "PDQ5 Question 2."},
    { "name": "questionThree", "type": "ThincItPdqQuestion", "doc": "PDQ5 Question 3."},
    { "name": "questionFour", "type": "ThincItPdqQuestion", "doc": "PDQ5 Question 4."},
    { "name": "questionFive", "type": "ThincItPdqQuestion", "doc": "PDQ5 Question 5."},
      { "name": "appVersion", "type": "int", "doc": "App version." }
  ]
}
