{
  "namespace": "org.radarcns.active.thincit",
  "type": "record",
  "name": "ThincItTrails",
  "doc": "THINC-it Assessment derived from Trail Making B. 17 trials. Each trial is the transition from one circle to another.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Timestamp in UTC (s) when the test is submitted to the subject." },
    { "name": "timeCompleted", "type": "double", "doc": "Timestamp in UTC (s) when the subject completes the test." },
    { "name": "score", "type": "int", "doc": "THINC-it index score - 0 to 4000." },
    { "name": "duration", "type": "int", "doc": "Total time taken to complete the assessment in milliseconds." },
    { "name": "layoutVersion", "type": "int", "doc": "Each play randomly select one of 40 pre-designed layouts." },
    { "name": "wrongNode", "type": "int", "doc": "The number of times that the subject transitioned to an incorrect next circle before successful transition to correct next circle." },
    { "name": "lostContact", "type": "int", "doc": "The number of times that the mouse button has been released before transitioning successfully to next circle." },
    { "name": "longestTrial", "type": "int", "doc": "Longest trial completion time expressed in milliseconds." },
    { "name": "iqrCompletion", "type": "int", "doc": "Mean of trial completion times within interquartile range." },
    { "name": "intervalOne", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalTwo", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalThree", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalFour", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalFive", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalSix", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalSeven", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalEight", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalNine", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalTen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalEleven", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalTwelve", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalThirteen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalFourteen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalFifteen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalSixteen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "intervalSeventeen", "type": "int", "doc": "Trial completion time in milliseconds." },
    { "name": "appVersion", "type": "int", "doc": "App version." }
  ]
}
