{
  "namespace": "org.radarcns.passive.phone",
  "type": "record",
  "name": "PhoneLight",
  "doc": "Data from the light sensor in luminous flux per unit area.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "light", "type": "float", "doc": "Illuminance (lx)." }
  ]
}
