{
  "namespace": "org.radarcns.passive.empatica",
  "type": "record",
  "name": "EmpaticaE4InterBeatInterval",
  "doc": "Time between individuals heart beats extracted from the BVP signal. You can compute the heart rate as (60 / ibi).",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "interBeatInterval", "type": "float", "doc": "The duration (s) of the detected inter-beat interval (i.e., the distance in seconds from the previous beat)." }
  ]
}
