{
  "namespace": "org.radarcns.connector.upload.altoida",
  "name": "AltoidaSummaryMetrics",
  "type": "record",
  "doc": "Metrics from a set of tests.",
  "fields": [
    {"name": "audioHighReactionTimes", "type": "float", "doc": "Distribution of reaction times to high tone(s)."},
    {"name": "audioHighAccuracy", "type": "float", "doc": "Distribution of deviation from speaker button center (cm)."},
    {"name": "audioLowReactions", "type": "int", "doc": "Distributions of number of reactions to low tones."},
    {"name": "audioIgnoredHighTonePercentage", "type": "float", "doc": "Distribution of ratio of high tones ignored."},
    {"name": "audioPrematureToneButtonPresses", "type": "int", "doc": "Distribution of number of premature tone button presses."},
    {"name": "randomScreenPressesDuringPlacement", "type": "int", "doc": "Distribution of number of random screen presses during the placement phase."},
    {"name": "randomScreenPressesDuringSearch", "type": "int", "doc": "Distribution of number of random screen presses during placement."},
    {"name": "tooMuchMovementCount", "type": "int", "doc": "Distribution of number of times placement was impossible due to too much movement."},
    {"name": "findBetterPlaceCount", "type": "float", "doc": "Number of times the user had to find a better place."},
    {"name": "introReadTimes", "type": "float", "doc": "Mean time the user required to read an intro page (s)."},
    {"name": "introReadTime1", "type": "float", "doc": "Time the user required to read the first intro page (s)."},
    {"name": "introReadTime2", "type": "float", "doc": "Time the user required to read the second intro page (s)."},
    {"name": "placeDelays", "type": "float", "doc": "Mean delay from possible placement to actual placement (s)."},
    {"name": "spotAlreadyTakenCount", "type": "int", "doc": "Number of times the user tried to use the same spot twice."},
    {"name": "trials", "type": {
      "type": "array",
      "items": "AltoidaTrial"
    }, "doc": "Per-trials details and analyses."},
    {"name": "trialMeans", "type": "AltoidaTrial", "doc": "Mean values of each of the trials."},
    {"name": "findFailCount", "type": "float", "doc": "Number of times the user failed to find an object."},
    {"name": "findSkipDurations", "type": "float", "doc": "Mean time the user tried before skipping an object in seconds."},
    {"name": "skipButtonCount", "type": "float", "doc": "Number of times the user pressed the skip button."},
    {"name": "countdownFail", "type": "float", "doc": "Number of countdown fails."},
    {"name": "stepCountRatio", "type": "float", "doc": "Distribution of the ratio between the steps needed for finding the objects over the steps needed for placing them."},
    {"name": "stepDelayP", "type": "float", "doc": "Mean delay between steps when placing objects (s)."},
    {"name": "stepDelayF", "type": "float", "doc": "Mean delay between steps when finding objects (s)."},
    {"name": "stepVarianceP", "type": "float", "doc": "Variance of delays between steps when placing objects."},
    {"name": "stepVarianceF", "type": "float", "doc": "Variance of delays between steps when finding objects."},
    {"name": "notWalkingTimeP", "type": "float", "doc": "Time the user did not walk during placing objects (s)."},
    {"name": "notWalkingTimeF", "type": "float", "doc": "Time the user did not walk during finding objects (s)."},
    {"name": "shockCount", "type": "float", "doc": "Number of shocks that were recorded during the test."},
    {"name": "accelerationVarianceX", "type": "float", "doc": "Variance of acceleration data of x axis."},
    {"name": "accelerationVarianceY", "type": "float", "doc": "Variance of acceleration data of y axis."},
    {"name": "accelerationVarianceZ", "type": "float", "doc": "Variance of acceleration data of z axis."},
    {"name": "strongHand", "type": "float", "doc": "Dominant hand of user."},
    {"name": "normalisationCircle", "type": "AltoidaWalkingTestAggregate", "doc": "Deviation from optimal path in circle normalisation test (cm)."},
    {"name": "normalisationSquare", "type": "AltoidaWalkingTestAggregate", "doc": "Deviation from optimal path in square normalisation test (cm)."},
    {"name": "normalisationSerpentine", "type": "AltoidaWalkingTestAggregate", "doc": "Deviation from optimal path in serpentine normalisation test (cm)."},
    {"name": "normalisationSpeedCircle", "type": "AltoidaWalkingTestAggregate", "doc": "Deviation from optimal path in speed circle normalisation test (cm)."},
    {"name": "normalisationRandomTapping", "type": "AltoidaTappingTestAggregate", "doc": "Deviation from center points in random tapping normalisation test (cm)."},
    {"name": "normalisationTapping", "type": "AltoidaTappingTestAggregate", "doc": "Deviation from center points in tapping normalisation test (cm)."}          
  ]
}
