{
  "namespace": "org.radarcns.passive.pebble",
  "type": "record",
  "name": "Pebble2BatteryLevel",
  "doc": "Device battery level.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "batteryLevel", "type": "float", "doc": "Battery level from 0 to 1." },
    { "name": "batteryIsCharging", "type": "boolean", "doc": "Whether the battery is being charged." },
    { "name": "batteryIsPlugged", "type": "boolean", "doc": "Whether the battery charger cable is plugged in." }
  ]
}
