{
  "namespace": "org.radarcns.connector.upload.altoida",
  "type": "record",
  "name": "AltoidaTouch",
  "doc": "Location where the user touched the touchscreen on an x and y axis. These values are calculated from the center of the screen in centimeters (cm).",
  "fields": [
    {"name": "time", "type": "double", "doc": "Timestamp in unix time acquired locally from the device."},
    {"name": "timeReceived", "type": "double", "doc": "Timestamp in unix time received from Altoida API."},
    {"name": "x", "type": "double", "doc": "Distance from the center of the screen in (cm)s on x-axis."},
    {"name": "y", "type": "double", "doc": "Distance from the center of the screen in (cm)s on y-axis."},
    {"name": "surface", "type": "double", "doc": "Diameter of the touch area in cm."},
    {"name": "accelerometer", "type": "double", "doc": "Acceleration exerted by the finger hitting the screen."},
    {"name": "combined", "type": "double", "doc": "An overall value of touch pressure formed from a linear combination of the previous columns."},
    {"name": "hit", "type": "boolean", "doc": "Whether the touch hit a button or not, 1 if the touch served a purpose basically, 0 otherwise."}
  ]
}
