{
  "namespace": "org.radarcns.passive.biovotion",
  "type": "record",
  "name": "BiovotionVsm1PpgRaw",
  "doc": "Raw 14bit Photodiode ADC (Analog to Digital conversion) data for red, green, IR and dark portions (PPG raw data).",
  "fields": [
    {"name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    {"name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    {"name": "red", "type": "float", "doc": "Raw red light ADC response (normalized 0 -16383)." },
    {"name": "green", "type": "float", "doc": "Raw green light ADC response (normalized 0 -16383)." },
    {"name": "ir", "type": "float", "doc": "Raw IR light ADC response (normalized 0 -16383)." },
    {"name": "dark", "type": "float", "doc": "Raw dark light ADC response (normalized 0 -16383)." }
  ]
}
