{
  "namespace": "org.radarcns.passive.biovotion",
  "type": "record",
  "name": "BiovotionVsm1Energy",
  "doc": "Energy expenditure data calculated by biovotion device.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "energyExpenditure", "type": "float", "doc": "Energy expenditure value (cal/s)." },
    { "name": "energyExpenditureQuality", "type": "float", "doc": "Energy expenditure quality (0-1)." }
  ]
}
