{
  "namespace": "org.radarcns.passive.phone",
  "type": "record",
  "name": "PhoneUserInteraction",
  "doc": "Logs change of user interaction state: when the phone is unlocked or set to standby.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "interactionState", "type": {
      "name": "PhoneInteractionState",
      "type": "enum",
      "doc": "Interaction type with an Android device.",
      "symbols": ["STANDBY", "UNLOCKED", "SHUTDOWN", "BOOTED", "OTHER"]
      }, "doc": "What interaction state the phone has." }
  ]
}
