{
  "namespace": "org.radarcns.passive.biovotion",
  "type": "record",
  "name": "BiovotionVsm1BatteryLevel",
  "doc": "Device battery state.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "batteryLevel", "type": "float", "doc": "Battery level (0-1)." },
    { "name": "batteryChargeRate", "type": "float", "doc": "Battery charge rate, level change per hour (0-1)." },
    { "name": "batteryVoltage", "type": "float", "doc": "Battery voltage (V)." },
    { "name": "batteryStatus", "type": "float", "doc": "Battery status; 0:not charging, not on charger; 2:not charging, on charger; 3:charging, on charger." }
  ]
}
