{
  "namespace": "org.radarcns.passive.empatica",
  "type": "record",
  "name": "EmpaticaE4BloodVolumePulse",
  "doc": "Data from photoplethysmograph.",
  "fields": [
    { "name": "time", "type": "double", "doc": "Device timestamp in UTC (s)." },
    { "name": "timeReceived", "type": "double", "doc": "Device receiver timestamp in UTC (s)." },
    { "name": "bloodVolumePulse", "type": "float", "doc": "Light absorption (nW)." }
  ]
}
