{
  "namespace": "org.radarcns.connector.upload.altoida",
  "type": "record",
  "name": "AltoidaAttitude",
  "doc": "Data from 3-axis, the attitude sensor provides the rotational position of the device in radians as unit.",
  "fields": [
    {"name": "time", "type": "double", "doc": "Timestamp in unix time acquired locally from the device."},
    {"name": "timeReceived", "type": "double", "doc": "Timestamp in unix time received from Altoida API."},
    {"name": "pitch", "type": "float", "doc": "Rotation of the x-axis (radians)."},
    {"name": "roll", "type": "float", "doc": "Rotation of the y-axis (radians)."},
    {"name": "yaw", "type": "float", "doc": "Rotation of the z-axis (radians)."}
  ]
}
